---
narrator: David Mayernik
subject: Disegno
facilitator: Nathan Schneider
date: 2025-06-18
approved: 2025-06-18
summary: "An artist and longtime professor at the University of Notre Dame's School of Architecture practices a kind of design that reaches across time and space."
location: "Lucca, Italy"
headshot: "david_mayernik.jpg"
topics: [architecture, art, urban planning]
links:
  - text: "Personal website"
    url: https://www.davidmayernik.com
  - text: "The Meaning of Rome: The Renaissance and Baroque City"
    url: https://www.edx.org/learn/humanities/university-of-notre-dame-the-meaning-of-rome-the-renaissance-and-baroque-city
---

*Your body of work includes oil painting, frescoes, opera sets, architecture, and more. How do you describe your practice, primarily?*

I would say I'm an architect only because architecture incorporates all those other things. If you say you're a painter, it's harder to pull architecture into it. Architecture can incorporate the other arts, while the other arts don't easily weave in architecture.

The people who were exclusively architects in the Renaissance in Italy were the exception. An architect was often someone who knew how to paint or sculpt. The Sangallo family—especially Antonio da Sangallo the Younger, who did a lot of palaces in Rome and was in charge of St. Peter's for a while—were thought of as architects. They came out of a woodworking tradition, and they weren't painters or sculptors. But most of the architects of the Renaissance were painters or sculptors first. Bramante was a painter before he became an architect, like Raphael and Leonardo—most people we think of as famous architects of the Renaissance were trained as something else.

Architecture was an extension of the other arts, and that had credibility because the fundamental skill that underlay all the arts was drawing. If you could draw, you could design anything. It was Bernini who said in the seventeenth century that architecture is pure *disegno*, pure drawing and design. Architecture is a manifestation of drawing more directly, but also in a more abstract way, than painting or sculpture.

Drawing is the thing that allows artists to migrate and do different things because it is conceptual. In Italian, *disegno* means both drawing and design, so beyond delineating it also means the ability to conceptualize. 

*What does that mean for the relationship between the drawing and the building? Is the building just an expression of the drawing, which is the ideal form?*

That's a really hot debate. A lot of people lament the fact that, in the Renaissance, building became the execution of somebody else's drawing. The romanticized idea about the Middle Ages is that there was no such thing as the architect—there was a master builder, and while they could draw, they were building their own buildings. They were both the executor and the conceiver of the building.

In the Renaissance that process gets segregated into the person who conceptualizes and somebody else who executes. It's not that the person who drew the building didn't have experience with materials—every painter in the Renaissance knew how to paint fresco, which is basically working with plaster, what most buildings were covered with. Understanding plaster means you also understand the masonry support for the plaster. In the modern era, architects rarely get their hands dirty with any material participation in the building process.

*Is there a particular time and place where you center your practice?*

I don't want to say I live in the past—I'm very much a modern person—but I do think people were very good at what they did in periods in the past that I aspire to. I would like to be as good as them. I'm not interested in replicating what they did or living in the past. My life would be completely different if I lived even one hundred years ago; I wouldn't be married to the woman I'm married to. I don't want to return to the past. But there's a lot we can learn from it.

My happy place—as much as I love the Renaissance—is that I'm really a Baroque guy, because I was formed in Rome, and Rome is a Baroque city more than anything else. My way of approaching things comes out of the late seventeenth, early eighteenth century—a time when things hadn't gotten too ideological as they would with neoclassicism. Somewhere in there is probably where my natural hand is, my way of working.

*How did Rome teach you?*

I tell my students now—which is not exactly how it happened for me—that you can't learn from Rome. You can learn from the people who worked in Rome. Rome is this overlay of accomplishment and transformation over thousands of years. You can't take Rome and transplant it elsewhere. It's such a unique response to its own position and history. But you can learn from the  many great architects who worked there. You can learn from Bernini or Raphael or Bramante.

There's a kind of romantic idea about *romanità*, a Romanness that you can bring to your work—a gravitas, a sense of seriousness, a weightiness that's very Roman. But there's a light, graceful side to Rome as well. You could take away a sensibility from Rome, but I think you can more directly, as an architect, learn from the architects, not from some vague feeling about Rome. I don't know how to take that and transplant it.

One of the things I tend to teach—which was controversial in my school—was that if you want to analyze something, you can only analyze something that was done intentionally. You can't analyze an accident or induce principles from a series of accidents, and a lot of what we have in Rome are accidents—things that happened without any design intent. The things you can actually apprehend and understand and learn from are the things that were done on purpose.

*As you're developing your practice in relationship to this place and its intentions and accidents, what kinds of rules or disciplines did you start adopting for yourself that, perhaps, other architects weren't adopting?*

When I was teaching at Notre Dame, a big part of the loose community of people who are roughly aligned with me—though we're actually more factionalized than many people understand—was a strong emphasis on urban design. By urban design, I mean the ways in which buildings play well together and contribute to something bigger than themselves, the making of streets and piazzas, the public realm.

One of the things I took away from Rome and emphasized when teaching was the role of buildings in shaping public space—that is one of their primary jobs. The role of buildings is to collaborate with other buildings to make public space. Unless you're building somebody's house in the middle of a field, anything in an urban context or even loosely related to an environment with other things around it has a responsibility to articulate and shape space and collaborate with other buildings.

*What are some of the ways that you do that, especially if you have buildings being built by different people at different times? How do you create the framework in which buildings collaborate around public space?*

If you're building in an existing urban context, the street system has already been determined, and unless you have some license to change how the street system works, your job is basically to reinforce that street system.

Creating public space in the American grid is challenging. If you want to create a plaza in an American city, the easiest thing is to remove one block of buildings and make it open space. Philadelphia has squares like that. Chicago has squares like that. One problem with them in terms of spatial definition is that usually the grid passes along the outside edges, making the corners kind of open. They don't have the same sense of containment with a closed corner that you have in European spaces, where streets often pass through the middle of the piazza. In Europe, you enter into the space rather than passing along its flanks.

For the TASIS school in Switzerland, I'm the master-plan architect, so I decide how the buildings relate to each other. If you're planning a campus, you have the responsibility and opportunity to organize buildings in ways that contribute to shaping space.

Some familiar campus plans include the college system at Princeton, Oxford, or Cambridge. The colleges are relatively self-contained, organized around a courtyard made by a grouping of buildings, like a monastery. They're all contiguous and collaborating in shaping a unique space. In that case the university is an accumulation of those colleges. A campus like Notre Dame is more like Harvard's, where it's an accumulation of individual buildings loosely organized around open quadrangles.

The TASIS Swiss campus is on a hillside, so it's really hard to connect the buildings and shape space in that monastic way. Because we're building it over time and the campus has evolved, it's an accumulation of discrete buildings that define and shape space, looser than a monastic model. The campus in Switzerland is more like a village.

I've tried—and it's actually been somewhat problematic for some people in the local planning department—to not make the Swiss campus look like there's a monotony of style. I've tried to particularize every building, give each their own unique character, but also respond to their specific type. The theater doesn't look like the gymnasium, which doesn't look like the library, so you can read the campus. As much as you want harmony between buildings, you also want special things to stand out or unique buildings to be legible as what they are. You can tell a church is different from a palace.

*When you're walking through the streets of a city—like here in Lucca—how do you see buildings interacting with each other?*

A city like Lucca is pretty harmonious. A lot of that happens in Italy because historically, people were building with a palette of materials that was constant over time. Masonry bearing wall buildings, mostly covered with stucco, are all going to harmonize almost by nature because of the constraints that masonry construction imposes on you—how big you can make openings, how many floors you can make a building. If you put a roof on, there are only so many ways of making eaves. There's a kind of natural harmony in most Italian cities, even if they're built over long periods of time, because the palette of materials was local and constant.

Lucca has a lot of brick because it doesn't have a lot of stone natively, while other cities are made more of stone because that was the indigenous building material. In the Italian tradition, brick is often just thought of as the structure, but the skin is stucco, and you can paint stucco any color you want.  Historically those colors were earth pigments, so you have a natural palette that's already harmonized.

In Lucca, there's not the same kind of coordinated spaces that we have in Rome. Some of the great piazzas that I loved in Rome are designed to be coordinated. Lucca doesn't have that—it's kind of a looser gentility. The buildings are all polite to each other, but they're not all cooperating in an orchestrated way.

*When you're working in relationship to these traditions, do you impose particular constraints on yourself or on people working within your master plan? Is there a sense of accountability to the tradition? Are there lines you try to avoid crossing that another architect might not?*

I'm the master planning architect for the campus, but I'm also designing all the buildings, so I'm true to myself in that sense. The project has stretched out over time—it's coming up on twenty-nine years I've been working for them, and we're still not done yet. Their needs have changed too.

What has held the project together is the idea of it as a village. The actual form of the village has changed; we've done a variety of master plans, and we've resubmitted the master plans for a variety of reasons. The core principle isn't the form, it's the intent—the idea that it wants to feel like a harmonious village. The form is evolving and changing, and I'm evolving and changing with it.

It's been interesting. I've had to adapt. I'm designing buildings now that are different from the ones I had imagined before. It's almost like I'm working in my own historical context, which I'm responsible for. I'm responsible for negotiating with my own buildings, with different needs and purposes that I didn't see coming twenty years ago.

I've imposed on the process—and it's been a long struggle and we're still battling with it—that all buildings would be built in masonry bearing wall construction. I personally want my buildings to be made the way they appear to be made. Not all architects care about that. Most buildings on the Notre Dame campus for the last half century look like brick buildings but are really steel-framed buildings with a brick skin.

I imposed on the school that the buildings should be what they look like, masonry bearing wall. We've more or less been true to that, with some recent compromises that bother me, but basically the buildings are what they appear to be. That process is slower and can cost more, which means you can't afford to do other stuff like use fancier materials, or have more columns or carvings.

They're pretty simple buildings, and I'm prepared to live with that. I would like to do more elaborate stuff, but I made a choice that we were going to build these things in a solid, durable way, and I had to give up other fancier elements that we might have been able to do otherwise. That's the choice I made—not every architect would do that.

At the school, I've done frescoes on the outside of the buildings. The theater has an iconographic program, and so does the gymnasium, which I interpreted in a more ancient, holistic cultural way as a place where you form the whole person, not just the body. I gave the gymnasium an iconographic program, but not all the buildings really need that or merit it.

I would love to do a chapel or a church someday, because it's a space where all the arts can collaborate. I think architecture is limited in terms of what it can say rhetorically or poetically. In order to say something specific, it needs painting and sculpture, and not all spaces need that.

*How does working in a context like a school compare to religious spaces that you've also engaged in? How do you approach the craft when the job involves a church?*

What I've done is paint a cycle of frescoes in a historic church in Tuscany. There's a whole story—there was an amazing unfolding of events, a consequence of preparing the wall to paint a frescoed crucifixion; they discovered an eighteenth-century fresco under the whitewash, so we had to move the crucifixion. It resulted in a whole other series of paintings in response to the one that they discovered.

While I was painting the crucifixion, the people who took over the school where I'd studied fresco technique were restoring the eighteenth-century fresco. It was super interesting because the past was coming back to life.

*What was the exchange like with that older painting that was uncovered? How did it affect what you were creating?*

The chapel had an oil painting of Mary and John at the foot of the cross from the late seventeenth century. They were two canvases that were meant to be together, the same size, mounted in a simple frame with a seam between them, and mounted over the seam was a wooden crucifix. This church happens to be next to the Tuscan home of my Swiss client. She paid for the renovation of the chapel and said, "My architect paints frescoes, and I think you should have a painted crucifix."

I made a choice that I did not want to imitate the oil on canvas historical paintings. I would paint the crucifix in fresco so that it would not be confused with the historical paintings, but would also complete the narrative of Mary and John at the foot of the cross. I wanted to paint the cross on the wall with the canvases hung on either side, so it would function as an ensemble in two different media.

It was supposed to be at the end wall of the chapel. But as they were scraping down the whitewash on that wall, they discovered there was an eighteenth-century painting, an Annunciation. So then the Belle Arti had to come in and decide what it was and how important it was. We decided to move the crucifix to the middle of one of the long walls.

Because the church is dedicated to a local saint who was the evangelist of that area in the early history of the church—the third century—and his martyrdom happened on the spot where the church was built, I was going to have an oval of the martyrdom of that saint over the crucifix. Because we had to move the crucifixion to a long wall under a pitched roof, that wall was shorter, and I couldn't fit the oval over the crucifix. I decided to slide the oval down behind the crucifix, like a window, and paint a series of five ovals around the rest of the upper part of the chapel, showing the whole cycle of the martyrdom of the patron saint.

By sacrificing something where the fresco was originally intended, it actually sponsored the creation of a richer narrative cycle about the martyrdom of the patron saint. I didn't actually show the martyrdom itself; I used the crucifixion where the martyrdom would have happened in the cycle. On one side of the crucifixion is the moment when the saint and his companions are captured by Roman soldiers. The moment after is where his decapitated skull is set up as the site of an altar that then sponsors the church. We lost the actual martyrdom because I thought the crucifixion, the paradigmatic martyrdom, could take the place of that scene. 

*What is the state of fresco painting today? Who still does it? Is it at risk of being a lost art?*

It was almost lost in the twentieth century. I got interested in it because of studying in Rome and wanting to paint and be an architect. I thought fresco was the perfect way to integrate the two. I knew someone who later became the Chairman at Notre Dame, an architect who dabbled in fresco; I asked him how he learned, and he said he read WPA manuals. During the 1930s, when they were trying to give work to artists and had artists painting murals in post offices and elsewhere, the fresco technique had sort of disappeared, so the WPA actually put out  manuals on how to do fresco painting.

I  found those manuals in the University of Pennsylvania Library, but I didn't really get it. Eventually I had the chance to study with a great restorer in Italy, Leonetto Tintori. He was one of the vehicles in Italy for continuing the fresco painting tradition.  He was an artist who, during World War II, got involved with preservation of frescoes in Pisa and then made a career out of it.

The other conduit was an artist named Pietro Annigoni, who was a portrait painter from Florence. He got wealthy painting portraits, including the Queen of England, and then essentially dedicated the rest of his life to painting frescoes pro bono for churches. He trained a whole generation of people, and one of them is a guy named Ben Long, an American who went back to North Carolina, and has done a whole series of frescoes there. Ben Long is probably the most famous fresco painter in the United States.

There was a vogue for it in the 80s and 90s, I think because of postmodernism in architecture. I feel like it's fading away now—there aren't a lot of people that I'm aware of doing it. In Italy, there are some people painting frescoes, including some of the students of Annigoni's students.

There's a Russian artist who painted the dome of the cathedral in Noto, Sicily, which was damaged by an earthquake. When they restructured the dome, they hired him to paint frescoes of the apostles—over life-size, super realistic, very impressive frescoes.

Fresco was practiced all over Europe historically. Here in Italy people are very cautious about introducing new things into old contexts. It's one of those things that's just not thought of mostly unless you're recreating a historic fresco for some reason or you're allowed to reintroduce a fresco in a damaged historic context. Most people don't think about frescoes in new building projects.

The onus is on architects to bring it into the discussion, but most architects don't have training in that kind of thing. They're not figurative artists themselves—they don't think that way. I've hired myself to do them for the school in Switzerland. I bring them into my own projects, but a lot of architects aren't thinking that way. They're thinking about just getting the building built.

*How do you see the overlap between these traditions and practices and the institutional authorities that set rules for preservation? How do you relate to the rules they impose?*

It's a pretty intense discussion, and the fact that it's actually softened a little bit recently is interesting. Italy has a hang-up—it's not unique to Italy, but it's really strong in Italy: this fear of something they call *falso storico* or "fake history." Essentially, doing new things that look like old things and creating ambiguity about what really is old versus what is new. That is a modern art historical or preservation mentality.

We have it in the United States too. The Secretary of the Interior's guidelines for historic preservation also essentially mandate that additions to historic buildings have to be in a distinctly different style, which is a very modern thing. It's a kind of obsession with imposing the zeitgeist.

Williamsburg is an interesting case of rebuilding, but Williamsburg is essentially a fake—a recreation of a city that was virtually non-existent. But mostly there's an aversion to doing that. In Italy it has been very much frowned upon to work in a traditional mode.

Pietro Annigoni was called in to paint the frescoes when they rebuilt Monte Cassino, and they decided not to replicate the old paintings that were there but create new ones. Annigoni's style does not look old-fashioned. There's something very modern about his work. I think self-consciously he didn't want to look like he was painting neo-Renaissance paintings. They're figurative, but there's a dark, almost menacing quality to a lot of his paintings—like somebody who lived through World War II and seen the worst of humanity and just can't paint happiness. There's a dark underbelly to a lot of his work. I don't think there was ever fear that his stuff would be confused with historical paintings, so he was allowed to do that in the 1960s.

Otherwise, working in historical contexts and painting new frescoes—people would rather do nothing. I think that attitude is softening. I was recently asked to do a big fresco for a monastery in the Marche. We had to get approval from the local Belle Arti, and we did get approval because it wasn't in the church. It was in a space that was basically kind of neutral—a whitewashed, vaulted historical space that didn't have any old art that could be confused with it. It was a new thing.

I think anybody who does something traditional in art or architecture in Italy is often thought of as being a forger or a falsifier. Restoring instead really means that you have something existing to restore.

The guy I studied fresco with had a philosophy about restoration: if you have a fresco that's missing something, you do not fill it in—you plaster the wall and leave them unpainted. You do not fill in the gaps, even if it wouldn't take a lot of imagination to do so. He was rigorous about not replicating or filling in missing bits in frescoes. But I do not share that philosophy.

There is also a tradition in Italy that when you have a missing bit, you can fill it in if you're pretty sure about what was missing; but you're supposed to do it in a technique that's distinguishable—not in true fresco. Let's say you have a purple drapery. The Italian technique is what they call *tratteggio*—it's hatching with little fine brushstrokes. You paint red, blue, red, blue, red, blue, and your eye from a distance reads it as purple. But up close you can see it's a hatching technique, so that future restorers a hundred years from now can distinguish what was original from what wasn't.

*Why do you disagree with your teacher's philosophy about filling in gaps?*

Historically, no one had a problem painting what was missing, scraping off a damaged fresco and painting a new one. That's how we have the history of art we have today. Michelangelo's Sistine ceiling was painted over a decorative blue sky with stars on it. Raphael came into the Stanza della Segnatura, where the School of Athens is, and there were already frescoes that had been begun, but they got rid of them, and he was allowed to start from scratch and repaint everything.

That fear of the past being something we have to cherish to the point at which it becomes untouchable is a really modern idea. I think it's because we have ruined so much stuff. There's a fear now that all we can do is something bad—we're so afraid of our own interventions in the modern world that there's a deep cultural assumption that we're focused on preventing the worst. We're not really interested in encouraging or allowing for the best because we don't trust ourselves.

*We also assume there's a kind of discontinuity or break—that we can't understand what people were trying to do in the past because we are modern now, and therefore we have no ability to be in relationship to that tradition.*

L. P. Hartley said that "the past is a foreign country; they do things differently there." I think there's a problem with the idea of going back to the past. The Renaissance—even though it was a renaissance, which means a "rebirth"—was not a recreation of antiquity. They didn't do neo-antique buildings. They did new buildings using the knowledge of the ancient world as they understood it, but to make new things for new purposes. Neoclassicism is something different. Neoclassicism was really an attempt to recreate antique forms. Everything looked like a temple. The Renaissance didn't do that.

I think we have to have a richer conversation about how you can learn from the past without replicating it. To not learn from the past is to impose on yourself a kind of cultural amnesia that I think is quite destructive. We should be capable of continuity without being afraid of doing a bad version of the past.

I had a professor who was a famous architectural theorist, Colin Rowe—a major theorist about architectural form and urbanism. When I was at the American Academy in Rome, I did a project to fill in the street that leads to St. Peter's; historically, it had been two streets. I presented it, and Colin came to my presentation. He said, "Isn't the problem with doing this kind of architecture that all you'll ever be is a mediocre version of the past?" I said that no, the onus is on us. I don't think there's something in the water or the air that keeps us from doing things as well as they did. It's just that the onus is on us to be as good as we possibly can be—to learn as much as we can. I don't think it's impossible to equal the past.

A lot of modernists assume that the past is so great, they revere it so much that they won't even try because they're afraid of failing. There's a cultural assumption in our world that if you really value the past, it's so great you can't ever achieve what it did, so you should just let it be its own thing and we do our own thing. That's deep in our culture.

*With that in mind, how do you teach your students to develop an architectural sense in cities with many layers? How do you teach them to see a historic city and understand their relationship to it?*

You have to teach principles. You shouldn't teach students to be mimics. You want them to be analytical and try to understand how the thing that they're looking at got to be the way it is. From that, you can induce principles—you can look at a series of particular cases and try to discern what was operating behind them. Those are the things that you can then apprehend and take with you and apply elsewhere, as opposed to mimicking a thing and replicating it.

You have to be able to peel away all the stuff that you see on the surface and try to figure out what the architect was thinking when they first started sketching. Design analysis is design in reverse—you're trying to unwind the process and get back to what was informing it. If you can do that, then that's where you can take the process with you, not the product. That's a big distinction. It's easier to copy—copying is pretty easy, actually. Analytical work, and apprehending a process, is a lot harder.

*How much do students have to know about history in order to understand historical work?*

It's definitely true that you get better at it the more you know. At some level, when you're a raw student and don't know much history, all you're doing is a kind of reacting to what they see. It's my job to give them a little bit of a backstory.

My sense of what schools should teach you is how to continue to learn after you get out of school. Not a repertoire, not a kit of parts or some tricks, but how to learn. That's a lifelong process, and you get better at it the longer you do it.

The more you do things of your own, the better you're able to understand what other people have done, and so that kind of iterative back-and-forth between practicing and studying and practicing and studying makes both of those exercises richer and better over time. I'm still a student—I'm still learning stuff—and I'm better at learning because I've done more things myself.

*Is there a particular building or place you keep coming back to that exemplifies the traditions and creative practice you've been trying to develop?*

In Rome, I think the most sophisticated piazza is Santa Maria della Pace, which was all designed by one architect, Pietro da Cortona, but dealing with existing urban conditions that were imperfect. He tried to mask or transform them into something that is more whole and perfect and woven together. It's almost  symphonic. It's this unbelievably rich dialogue between the church and the fabric of buildings around it. You can't extrapolate that or take that and transplant it elsewhere, but you can definitely try to do that kind of weaving and stitching of things together.

At the Swiss campus, it's a little more call and response. There are ways in which certain things in certain buildings talk to or say things to other buildings. In the gym I painted a fresco at the top of a flight of stairs that climbs about twenty-three feet; when you get to the back there is a loggia. The  fresco I painted in the loggia is the Choice of Hercules, which is supposed to be this idea that he's visited by two female figures that represent virtue and vice. Vice isn't a dissolute life. She offers him a life of ease in the shady grove, but Virtue shows him the hard, rocky, uphill path to fame.

The rest of the hillside was the harder part of the campus to be built, and I didn't know if they were ever going to build it because it was challenging. So I have Virtue pointing uphill with a trowel, basically an admonition to the school to build the rest of the campus, the hard part. And eventually they did, within about ten years.

On the facade of the building at the top of the hill—I designed it and had somebody else paint it—there are two big cornucopias with this great bounty flowing down. The reward for the hard path of climbing the hill is all this good stuff that cascades down on you. When you get up to that building, there's a big arched passage in the stairway, and from there you look out over the Alps and Lake Lugano. It's definitely a reward for having climbed the hill.

I set up a dynamic and told the end of the story when I had the opportunity to do that. But mostly people don't know those stories are there. The students don't know it unless somebody reinforces it or tells them that it's there, as the current headmaster has done. It can be read like a text, even if not everybody has the tools to read it.

*What kinds of responses have you experienced to what you're trying to communicate in architecture? How do people respond to your work? How does it surprise you?*

I think people respond to stories. I had a great professor who taught me a design process but was also really big on the idea that architecture could be narrative—that it can unfold or tell stories—and I think people are really captivated by that. I think the extent to which you can treat your environment as a place that you can read, like it actually has messages—not every environment has it, somebody has to put them there. Most places have a history, and so there's a kind of unspoken story that's often the history of a place.

I do think it's one of our jobs, apart from making buildings behave well together, to tell stories in some way or to contribute to some larger story that our society wants to tell about itself. I think we're desperate for it, actually. We want to believe our world makes sense somehow, and I think we need that. Sometimes people have said you could read our Constitution in the layout of the National Mall and the disposition of buildings in the center of Washington, DC. I think the extent to which our environment, especially in the United States, could do more of that—it could be one of the things that gives us a sense of shared purpose and a sense of what we have in common.

We have enough in common that we can tell some stories. One of the things I get when I present the idea that architecture can be narrative is a lot of people say, "Well, we don't have enough shared stories that everybody could agree on." I don't think that's actually true. I think we have more in common than we think. Often it's the interpretation of our stories that we argue about. If we didn't have some shared principles that allow us to deal with each other every day—those are maybe the protocols, the things underneath who we are—instead of using them as partisan divides, we could be using them as ways of unifying us.

*You can imagine the stories in a village where everybody's going to the same places all the time and everything is marked with meaning—this happened there, this happened there. On the opposite end is this kind of fascist propaganda, which is like the looming building that's telling you exactly one story and you know what's wrong in some way. There has to be something in between.*

There's a difference between iconography and propaganda. I think, historically, most societies talked about who they wanted to be, not who they were. I don't know if you know the _Allegory of Good and Bad Government_ in Siena in the Palazzo Pubblico. It's amazing. It's sometimes called "The Allegory of the Effects of Good and Bad Government in the City." It doesn't really talk about how the government worked. It talked about the ideals that allowed the government to function.

In the allegory of good government, what seems to be a ruler—it's a guy who looks like a king with a sword—is actually *bene comune*, the common good. The ruler of the city is the common good. Through a whole series of connections, he holds a sword that is ultimately tethered to a rope that's being carried by citizens from the figure of Concordia, who's taking two ropes that pass down from the scales of justice. Concordia weaves the rope together and passes it on to the citizens, and the citizens hand it on to the Common Good.

Nobody's going to argue with that. Basically, social concord comes from justice, and it's conveyed to the authorities—who really are themselves just representatives of the common good—by the civic body, by the people of the city. We all want that. That's fourteenth-century Siena, but at some level that's how good, healthy societies operate today, I think.

So I think allegorical messages used to be more based on principles and values, rather than mandating particular kinds of behavior. They were basically shared senses of purpose, and they were aspirational. They tell you, "Here are the virtues, here are the things we need in order to be able to do this," but then the actual mechanics of governance—who knows if Siena ever was like that? They were obviously saying, "We believe this is who we are," but it was probably better than who they were, and it didn't impose anything on anybody other than a shared sense of responsibility.

We shouldn't have a hard time doing that today. I think everybody's too vested in the idea that we're slugging it, out instead of trying to figure out what we could actually share. Ultimately, iconography shouldn't be that mechanistic and specific—it should be more broad and general. You shouldn't be able to argue with the principles; if there's major dissent about the principles, something's wrong.

The statues of Civil War leaders—that's problematic because there is all kinds of stuff behind that was wrong. Whereas celebrating justice—who doesn't want justice? A statue of truth—we should all want that. If we didn't want a statue of truth, that would be a problem.
